==> ssp-center-api-1.1.22-yqf-20221128.101114-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/UndeadLinkDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
@Data
public class UndeadLinkDto implements Serializable {
    private Long id;

    private String link;

    private Integer wxClickStatus;

    private Integer wxScanStatus;

    private Integer status;

    private String bindSlotList;

    private Integer bindSlotNum;

    private Date gmtCreate;

    private Date gmtModified;

    private String sceneType;

    private static final long serialVersionUID = 1L;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getLink() {
        return link;
    }

    public void setLink(String link) {
        this.link = link == null ? null : link.trim();
    }

    public Integer getWxClickStatus() {
        return wxClickStatus;
    }

    public void setWxClickStatus(Integer wxClickStatus) {
        this.wxClickStatus = wxClickStatus;
    }

    public Integer getWxScanStatus() {
        return wxScanStatus;
    }

    public void setWxScanStatus(Integer wxScanStatus) {
        this.wxScanStatus = wxScanStatus;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getBindSlotList() {
        return bindSlotList;
    }

    public void setBindSlotList(String bindSlotList) {
        this.bindSlotList = bindSlotList == null ? null : bindSlotList.trim();
    }

    public Integer getBindSlotNum() {
        return bindSlotNum;
    }

    public void setBindSlotNum(Integer bindSlotNum) {
        this.bindSlotNum = bindSlotNum;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getSceneType() {
        return sceneType;
    }

    public void setSceneType(String sceneType) {
        this.sceneType = sceneType;
    }
}

==> ssp-center-api-1.1.52-yqf-20230315.062602-13-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/UndeadLinkDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
@Data
public class UndeadLinkDto implements Serializable {


    private static final long serialVersionUID = 1L;

    private Long id;

    private Long slotId;

    private String link;

    private Integer wxClickStatus;

    private Integer wxScanStatus;

    private Integer status;

    private String bindSlotList;

    private Integer bindSlotNum;

    private Date gmtCreate;

    private Date gmtModified;

    private String sceneType;

    private Integer tuParamStatus;

    private Long appId;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getTuParamStatus() {
        return tuParamStatus;
    }

    public void setTuParamStatus(Integer tuParamStatus) {
        this.tuParamStatus = tuParamStatus;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getLink() {
        return link;
    }

    public void setLink(String link) {
        this.link = link == null ? null : link.trim();
    }

    public Integer getWxClickStatus() {
        return wxClickStatus;
    }

    public void setWxClickStatus(Integer wxClickStatus) {
        this.wxClickStatus = wxClickStatus;
    }

    public Integer getWxScanStatus() {
        return wxScanStatus;
    }

    public void setWxScanStatus(Integer wxScanStatus) {
        this.wxScanStatus = wxScanStatus;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getBindSlotList() {
        return bindSlotList;
    }

    public void setBindSlotList(String bindSlotList) {
        this.bindSlotList = bindSlotList == null ? null : bindSlotList.trim();
    }

    public Integer getBindSlotNum() {
        return bindSlotNum;
    }

    public void setBindSlotNum(Integer bindSlotNum) {
        this.bindSlotNum = bindSlotNum;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getSceneType() {
        return sceneType;
    }

    public void setSceneType(String sceneType) {
        this.sceneType = sceneType;
    }
}
